@@ -3,17 +3,17 @@
 #
 # ***** BEGIN LICENSE BLOCK *****
 # Copyright (C) 2012-2014  Hayaki Saito <user@zuse.jp>
-# 
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ***** END LICENSE BLOCK *****
@@ -43,7 +43,9 @@ from iomode import IOMode
 class MockController():
     pass
 
+
 class SwitchOnOffTrait():
+
     """
     >>> controller = MockController
     >>> output_file = StringIO()
@@ -224,8 +226,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
         if not self._xterm_mouse_buffer is None and self._io_mode.is_input():
             buf = self._xterm_mouse_buffer
             buf.append(c)
-            self._xterm_mouse_counter -= 1;
-            buflen = len(buf)
+            self._xterm_mouse_counter -= 1
             if self._xterm_mouse_counter == 0:
                 self._xterm_mouse_buffer = None
                 self.handle_xterm_mouse(context, buf)
@@ -276,12 +277,12 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
             info = (seq[3] - 32, seq[4] - 32, seq[5] - 32)
             value = "xterm normal mouse: button=%d, x=%d, y=%d" % info
             params = (prompt, seq[3], seq[4], seq[5], value)
-            self._buffer.write(template.getmouse() % params)
+            self._buffer.write(unicode(template.getmouse()) % params)
         elif seq[2] == 0x74:  # t
             info = (seq[3] - 32, seq[4] - 32)
             value = "xterm highlight mouse: x=%d, y=%d" % info
             params = (prompt, seq[3], seq[4], value)
-            self._buffer.write(template.gethighlightmouseinitial() % params)
+            self._buffer.write(unicode(template.gethighlightmouseinitial()) % params)
         elif seq[2] == 0x54:  # T
             info = (seq[3] - 32, seq[4] - 32, seq[5] - 32,
                     seq[6] - 32, seq[7] - 32, seq[8] - 32)
@@ -289,7 +290,7 @@ class TraceHandler(tff.DefaultHandler, SwitchOnOffTrait):
                      'endx=%d, endy=%d, mousex=%d, mousey=%d') % info
             params = (prompt, seq[3], seq[4], seq[5],
                       seq[6], seq[7], seq[8], value)
-            self._buffer.write(template.gethighlightmouse() % params)
+            self._buffer.write(unicode(template.gethighlightmouse()) % params)
 
     def handle_resize(self, context, row, col):
         if self.is_disabled():
